# Docker

## Build

    ./build.sh

## Execução

Para executar é necessário exportar as seguintes portas:

+ 8010 (REST Services)
+ 1099 (RMI)
+ 6681 (FTC)
+ 8080 (Tomcat)
+ 7778 (SGA)
+ 7878 (SGA SSL)
+ 7779 (WIO)
+ 40500 (SGA REST)

Os seguintes volumes:

+ /csgrid/projects (área de projetos)
+ /csgrid/algorithms (repositório de algoritmos)
+ /csgrid/security (diretório contendo as chaves). Para o serviço REST é necessário exitir uma chave com o nome _rest_api_token_key_.
+ /csgrid/persist (área de persistência)
+ /csgrid/logs (diretório de log)

E por fim, a variável de ambiente _CSGRID_HOST_NAME_ deve ser definida usando a opção _-e_ do comando docker run.

Por exemplo:

    docker run --rm \
    -p 8010:8010 \
    -p 1099:1099 \
    -p 6681:6681 \
    -p 8080:8080 \
    -p 7778:7778 \
    -p 7878:7878 \
    -p 7779:7779 \
    -p 40500:40500 \
    -v /home/csgrid/persist:/csgrid/persist \
    -v /home/csgrid/projects:/csgrid/projects \
    -v /home/csgrid/algorithms:/csgrid/algorithms \
    -v /home/csgrid/security:/csgrid/security \
    -v /home/csgrid/logs:/csgrid/logs \
    -e "CSGRID_HOST_NAME=localhost" \
    -e "CSGRID_RMI_EXPORT_PORT=1099" \
    csbase/csgrid:ERAS-2.7.2-SNAPSHOT

## Build de imagem com dados iniciais

    docker build -f Dockerfile-with-data -t csbase/csgrid:2.7.2-SNAPSHOT-with-data .

## Execução de imagem com dados iniciais

    docker run \
    -p 8010:8010 \
    -p 1099:1099 \
    -p 6681:6681 \
    -p 8080:8080 \
    -p 7778:7778 \
    -p 7878:7878 \
    -p 7779:7779 \
    -p 40500:40500 \
    -e "CSGRID_HOST_NAME=localhost" \
    -e "CSGRID_RMI_EXPORT_PORT=1099" \
    csbase/csgrid:2.7.2-SNAPSHOT-with-data

## Execução em conjunto com um SGA + novo histórico de comandos

O arquivo docker-compose.yml inicia o CSGrid, o SGA e a infra-estrutura para o novo histórico de comandos. Para usá-lo é necessário definir a variável de ambiente _HOSTNAME_ com o nome da máquina hospedeira. Os seguintes diretórios devem existir dentro do diretório corrente:
+ csgrid_data/persist
+ csgrid_data/security
+ csgrid_data/projects
+ csgrid_data/algorithms
+ csgrid_data/logs

Para executar:

    export HOSTNAME=`hostname`
    docker-compose up

Para executar a versão com dados:

    export HOSTNAME=`hostname`
    docker-compose -f docker-compose-with-data.yml up

Para executar um cliente:

    javaws "http://<hostname>:8080/csgrid/init" (ou abrir esta url no browser)
* No cliente temos 2 usuários (*admin* e *tester*), ambos com password *1234*.

Para limpar ambiente:

    docker-compose down

Para limpar ambiente da versão com dados:

    docker-compose -f docker-compose-with-data.yml down

Como o docker-compose cria volumes (docker_algorithms, docker_projects) na máquina local, pode ser necessário apagar esses volumes para resetar os dados do docker:

    docker volume ls
    docker volume rm <nome do volume>


## Teste de submeter vários jobs para execução usando o docker-compose acima com dados:

O seguinte comando executa, com o usuário "tester", 100 jobs do algoritmo "Teste_Progresso", versão "1.0.0", no projeto "TestProject-tester": 
```
  curl -X POST \
    http://localhost:8010/v1/jobs/ \
    -H 'Authorization: Bearer eyJhbGciOiJIUzUxMiJ9.eyJzdWIiOiJ0ZXN0ZXIiLCJleHAiOjE4NjgzNTk3OTcsImlhdCI6MTU1Mjk5OTc5N30.DRqEzpEuSgJaKKyTfDd7unUBE3SnAe_LG1NFLqqii5wvKKk8JWu4KLT4bMK2eFjyL1WaDo7aMB7EW_ZsVLdXjw' \
    -H 'Cache-Control: no-cache' \
    -H 'Content-Type: application/json' \
    -H 'Postman-Token: 658a02cd-5754-4df6-9687-20ad4f01867a' \
    -d '{"description": "teste de progresso", "remoteCommand": { "algorithmId": "Teste_Progresso", "versionId": "1.0.0", "projectId": "dGVzdGVyL1Rlc3RQcm9qZWN0LXRlc3Rlcg=="}, "args": {"qtde":5, "duracao":1}, "priority" :0, "numberOfJobs":100}'

```
## Teste para submeter um job com diversos tipos de parâmetros:
O seguinte comando executa, com o usuário "tester", 1 job do algoritmo "Teste_parametros", versão "1.0.0", no projeto "TestProject-tester": 
```
curl -X POST \
   http://localhost:8010/v1/jobs/ \
   -H 'Authorization: Bearer eyJhbGciOiJIUzUxMiJ9.eyJzdWIiOiJ0ZXN0ZXIiLCJleHAiOjE4NjgzNTk3OTcsImlhdCI6MTU1Mjk5OTc5N30.DRqEzpEuSgJaKKyTfDd7unUBE3SnAe_LG1NFLqqii5wvKKk8JWu4KLT4bMK2eFjyL1WaDo7aMB7EW_ZsVLdXjw' \
   -H 'Cache-Control: no-cache' \
   -H 'Content-Type: application/json' \
   -H 'Postman-Token: 658a02cd-5754-4df6-9687-20ad4f01867a' \
   -d '{"description": "a teste de progresso", "remoteCommand": { "algorithmId": "Teste_parametros", "versionId": "1.0.0", "projectId": "dGVzdGVyL1Rlc3RQcm9qZWN0LXRlc3Rlcg=="}, "args": {"bool":true,
"integer":50, "real":0.5, "text":"text1", "integer_list":[1,2,3,4], "real_list":[1.4,1.2,1.8,8.5], "text_list":["textA","textB","textC"], "enumeration_single":"item_1_id",
"enumeration_multiple":["item_1_id","item_2_id","item_3_id"], "input_file_txt":"novoArquivo", "input_dir":".", "input_dir_root":".", "input_file_or_dir":"novoArquivo",
"input_file_multiple":["novoArquivo"], "output_file_txt":"novoArquivo", "output_dir":".", "output_dir_root":".", "output_file_multiple":["novoArquivo"],
"table":[[1,1.5,"linha1"],[2,1.2,"linha2"],[3,2.5,"linha3"],[4,1.5,"linha4"]], "LOG_FILE":"novoArquivo"}, "priority" :0, "numberOfJobs":1}' 
```

